@@ -125,17 +125,12 @@ class AccessoryMDNSServiceInfo(ServiceInfo):
         self.state = state
 
         adv_data = self._get_advert_data()
+        valid_name = self._valid_name()
+        short_mac = self.state.mac[-8:].replace(":", "")
         # Append part of MAC address to prevent name conflicts
-        name = "{} {}.{}".format(
-            self._valid_name(),
-            self.state.mac[-8:].replace(":", ""),
-            HAP_SERVICE_TYPE,
-        )
-        server = zeroconf_server or "{}-{}.{}".format(
-            self._valid_host_name(),
-            self.state.mac[-8:].replace(":", ""),
-            "local.",
-        )
+        name = f"{valid_name} {short_mac}.{HAP_SERVICE_TYPE}"
+        valid_host_name = self._valid_host_name()
+        server = zeroconf_server or f"{valid_host_name}-{short_mac}.local."
         super().__init__(
             HAP_SERVICE_TYPE,
             name=name,
@@ -631,6 +626,7 @@ class AccessoryDriver:
         Must be run in the event loop.
         """
         loop = asyncio.get_event_loop()
+        logger.debug("Scheduling write of accessory state to disk")
         asyncio.ensure_future(loop.run_in_executor(None, self.persist))
 
     def persist(self):
@@ -638,6 +634,7 @@ class AccessoryDriver:
 
         Must run in executor.
         """
+        logger.debug("Writing of accessory state to disk")
         tmp_filename = None
         try:
             temp_dir = os.path.dirname(self.persist_file)
@@ -646,7 +643,13 @@ class AccessoryDriver:
             ) as file_handle:
                 tmp_filename = file_handle.name
                 self.encoder.persist(file_handle, self.state)
+            if os.name == 'nt':  # Or `[WinError 5] Access Denied` will be raised on Windows
+                os.chmod(tmp_filename, 0o644)
+                os.chmod(self.persist_file, 0o644)
             os.replace(tmp_filename, self.persist_file)
+        except Exception:  # pylint: disable=broad-except
+            logger.exception("Failed to persist accessory state")
+            raise
         finally:
             if tmp_filename and os.path.exists(tmp_filename):
                 os.remove(tmp_filename)
@@ -677,7 +680,9 @@ class AccessoryDriver:
         :return: Whether the pairing is successful.
         :rtype: bool
         """
-        logger.info("Paired with %s.", client_uuid)
+        logger.info(
+            "Paired with %s with permissions %s.", client_uuid, client_permissions
+        )
         self.state.add_paired_client(client_uuid, client_public, client_permissions)
         self.async_persist()
         return True
@@ -806,10 +811,16 @@ class AccessoryDriver:
                     rep[HAP_REPR_VALUE] = char.get_value()
                     rep[HAP_REPR_STATUS] = HAP_SERVER_STATUS.SUCCESS
             except CharacteristicError:
-                logger.error("Error getting value for characteristic %s.", id)
+                logger.error(
+                    "%s: Error getting value for characteristic %s.",
+                    self.accessory.display_name,
+                    (aid, iid),
+                )
             except Exception:  # pylint: disable=broad-except
                 logger.exception(
-                    "Unexpected error getting value for characteristic %s.", id
+                    "%s: Unexpected error getting value for characteristic %s.",
+                    self.accessory.display_name,
+                    (aid, iid),
                 )
 
             chars.append(rep)
